@@ -23,27 +23,6 @@
 
 #include <algorithm>
 
-/*#ifdef USE_TR1_UNORDERED_MAP
-#include <tr1/unordered_map>
-using std::tr1::unordered_map;
-using std::tr1::unordered_multimap;
-#else
-#include <unordered_map>
-using std::unordered_map;
-using std::unordered_multimap;
-#endif
-
-#ifdef USE_TR1_UNORDERED_SET
-#include <tr1/unordered_set>
-using std::tr1::unordered_set;
-using std::tr1::unordered_multiset;
-#else
-#include <unordered_set>
-using std::unordered_set;
-using std::unordered_multiset;
-#endif*/
-
-
 #include <string>
 #include <utility>
 using std::pair; using std::make_pair;
