@@ -16,8 +16,12 @@
 #if HAVE_FOMA
 
 #ifndef _FOMALIB_H_
-#define _FOMALIB_H_
-#include "back-ends/foma/fomalib.h"
+  #define _FOMALIB_H_
+  #ifdef HAVE_FOMA_UPSTREAM
+    #include <fomalib.h>
+  #else
+    #include "back-ends/foma/fomalib.h"
+  #endif
 #endif
 
 #include "FomaTransducer.h"
@@ -58,7 +62,7 @@ namespace hfst { namespace implementations {
     FomaInputStream::FomaInputStream(const std::string &filename_):
       filename(std::string(filename_))
   {
-    if (filename == std::string())
+    if (filename.empty())
       { input_file = stdin; }
     else {
       input_file = hfst::hfst_fopen(filename.c_str(),"r");
@@ -79,7 +83,7 @@ namespace hfst { namespace implementations {
     input_file = NULL;
       }
   }
-  
+
   char FomaInputStream::stream_get() {
     return (char) fgetc(input_file); }
 
@@ -100,22 +104,22 @@ namespace hfst { namespace implementations {
     ungetc(c, input_file);
     return retval;
   }
-  
+
   bool FomaInputStream::is_bad(void)
   {
     return is_eof();
   }
-  
+
   bool FomaInputStream::is_good(void)
   {
     return ! is_bad();
   };
-  
+
   bool FomaInputStream::is_fst(void)
   {
     return is_fst(input_file);
   }
-  
+
   bool FomaInputStream::is_fst(FILE * f)
   {
     if (f == NULL)
@@ -124,7 +128,7 @@ namespace hfst { namespace implementations {
     ungetc(c, f);
     return c == 31 || c == (int)'#';
   }
-  
+
   bool FomaInputStream::is_fst(std::istream &s)
   {
     int c = s.peek();
@@ -143,7 +147,7 @@ namespace hfst { namespace implementations {
       {
         HFST_THROW(NotTransducerStreamException); }
   }
-  
+
   void FomaInputStream::skip_hfst_header(void)
   {
     char hfst_header[6];
@@ -202,7 +206,7 @@ namespace hfst { namespace implementations {
   {
     fputc(c,ofile);
   }
-    
+
     void FomaOutputStream::write_transducer(fsm * transducer)
   {
     if (1 != FomaTransducer::write_net(transducer, ofile)) {
@@ -212,18 +216,22 @@ namespace hfst { namespace implementations {
     }
   }
 
-  
+  FomaTransducer::FomaTransducer() {
+    _Bool val = 1;
+    fsm_set_option(FSMO_SKIP_WORD_BOUNDARY_MARKER, &val);
+  }
+
   fsm * FomaTransducer::create_empty_transducer(void)
   {
     fsm * retval = fsm_empty_set();
     return retval;
   }
-  
+
   fsm * FomaTransducer::create_epsilon_transducer(void)
   {
     return fsm_empty_string();
   }
-  
+
   void FomaTransducer::harmonize(fsm *net1, fsm *net2)
   {
     fsm_merge_sigma(net1, net2);
@@ -255,12 +263,12 @@ namespace hfst { namespace implementations {
                               fsm_symbol(const_cast<char*>(osymbol.c_str())) );
     // should either argument be deleted?
   }
-  
+
   fsm * FomaTransducer::define_transducer(const StringPairVector &spv)
   {
     if (spv.empty())
       return fsm_empty_string();
-    
+
     int state_number=0;
 
     struct fsm_construct_handle *h;
@@ -268,7 +276,7 @@ namespace hfst { namespace implementations {
     char * empty = strdup(std::string("").c_str());
     h = fsm_construct_init(empty);
     free(empty);
-    
+
     for (StringPairVector::const_iterator it = spv.begin();
          it != spv.end(); it++)
       {
@@ -278,7 +286,7 @@ namespace hfst { namespace implementations {
         free(in); free(out);
         state_number++;
       }
-    
+
     fsm_construct_set_initial(h, 0);
     fsm_construct_set_final(h, state_number);
 
@@ -288,7 +296,7 @@ namespace hfst { namespace implementations {
     sigma_add_special (0, net->sigma);
     sigma_add_special (1, net->sigma);
     sigma_add_special (2, net->sigma);
-    
+
     return net;
   }
 
@@ -296,27 +304,27 @@ namespace hfst { namespace implementations {
   {
     if (sps.empty())
       return fsm_empty_string();
-    
+
     int source=0;
     int target = (cyclic) ? 0 : 1;
 
     struct fsm_construct_handle *h;
     fsm *net;
     h = fsm_construct_init(strdup(std::string("").c_str()));
-    
+
     for (StringPairSet::const_iterator it = sps.begin(); it != sps.end(); it++)
       {
     char *in = strdup(it->first.c_str());
     char *out = strdup(it->second.c_str());
     fsm_construct_add_arc(h, source, target, in, out);
       }
-    
+
     fsm_construct_set_initial(h, source);
     fsm_construct_set_final(h, target);
 
     net = fsm_construct_done(h);
     fsm_count(net);
-    
+
     return net;
   }
 
@@ -325,13 +333,13 @@ namespace hfst { namespace implementations {
   {
     if (spsv.empty())
       return fsm_empty_string();
-    
+
     int state_number=0;
 
     struct fsm_construct_handle *h;
     fsm *net;
     h = fsm_construct_init(strdup(std::string("").c_str()));
-    
+
     for (std::vector<StringPairSet>::const_iterator it = spsv.begin();
          it != spsv.end(); it++)
       {
@@ -343,13 +351,13 @@ namespace hfst { namespace implementations {
         }
         state_number++;
       }
-    
+
     fsm_construct_set_initial(h, 0);
     fsm_construct_set_final(h, state_number);
 
     net = fsm_construct_done(h);
     fsm_count(net);
-    
+
     return net;
   }
 
@@ -357,7 +365,7 @@ namespace hfst { namespace implementations {
   {
     return fsm_copy(t);
   }
-  
+
   fsm * FomaTransducer::determinize(fsm * t)
   {
     // returns the argument, so a copy is taken here
@@ -375,61 +383,61 @@ namespace hfst { namespace implementations {
     // returns the argument, so a copy is taken here
     return fsm_epsilon_remove(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::repeat_star(fsm * t)
   {
     return fsm_kleene_star(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::repeat_plus(fsm * t)
   {
     return fsm_kleene_plus(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::repeat_n(fsm * t, unsigned int n)
   {
     return fsm_concat_n(fsm_copy(t), n);
   }
-  
+
   fsm * FomaTransducer::repeat_le_n(fsm * t, unsigned int n)
   {
     return fsm_concat_m_n(fsm_copy(t),0,n);
   }
-  
+
   fsm * FomaTransducer::optionalize(fsm * t)
   {
     return fsm_optionality(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::invert(fsm * t)
   {
     return fsm_invert(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::reverse(fsm * t)
   {
     return fsm_reverse(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::extract_input_language(fsm * t)
   {
     // foma does not handle epsilon transducer properly..
     return fsm_upper(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::extract_output_language(fsm * t)
   {
     // foma does not handle epsilon transducer properly..
     return fsm_lower(fsm_copy(t));
   }
-  
+
   fsm * FomaTransducer::substitute(fsm * t,String old_symbol,String new_symbol)
   {
     return fsm_substitute_symbol(t,
                                  strdup(old_symbol.c_str()),
                                  strdup(new_symbol.c_str()));
   }
-  
+
     /* Conversion to HfstBasicTransducer is now used instead. */
   fsm * FomaTransducer::insert_freely(fsm * t, const StringPair &symbol_pair)
   {
@@ -458,7 +466,7 @@ namespace hfst { namespace implementations {
   // marker should be removed from sigma..
   // (HfstBasicTransducer is now used instead)
   }
-  
+
   fsm * FomaTransducer::compose
   (fsm * t1, fsm * t2)
   {
@@ -496,7 +504,7 @@ namespace hfst { namespace implementations {
       fsm_union(fsm_minus(fsm_copy(t1),fsm_copy(t2)),
                 fsm_minus(fsm_copy(t2),fsm_copy(t1)));
     int eq = fsm_isempty(test);
-    //fsm_destroy(test);
+    fsm_destroy(test);
     return (eq == 1);
   }
 
@@ -505,7 +513,7 @@ namespace hfst { namespace implementations {
     fsm_topsort(t);
     return !(t->is_loop_free);
   }
-  
+
     unsigned int FomaTransducer::number_of_states(fsm * t)
     {
       unsigned int retval=0;
@@ -530,7 +538,7 @@ namespace hfst { namespace implementations {
       return retval;
     }
 
-  
+
   static bool extract_paths
   (fsm * t, int state,
    std::map<int,unsigned short> all_visitations,
@@ -548,7 +556,7 @@ namespace hfst { namespace implementations {
     // Increment number of visitations
     all_visitations[state]++;
     path_visitations[state]++;
-    
+
     if (spv.size() != 0)
       {
         //check finality
@@ -562,7 +570,7 @@ namespace hfst { namespace implementations {
                 break;
               }
           }
-        
+
         hfst::HfstTwoLevelPath path(float(0), spv);
         hfst::ExtractStringsCb::RetVal ret = callback(path, final);
         if(!ret.continueSearch || !ret.continuePath)
@@ -571,7 +579,7 @@ namespace hfst { namespace implementations {
             return ret.continueSearch;
           }
       }
-    
+
 
     // find and sort transitions
     std::vector<fsm_state*> sorted_arcs;
@@ -596,9 +604,9 @@ namespace hfst { namespace implementations {
     for(size_t i=0; i<sorted_arcs.size() && res == true; i++)
     {
       fsm_state* arc = sorted_arcs[i];
-      
+
       bool added_fd_state = false;
-      
+
       if (fd_state_stack) {
         if(fd_state_stack->back().get_table().get_operation(arc->in) != NULL) {
           fd_state_stack->push_back(fd_state_stack->back());
@@ -610,13 +618,13 @@ namespace hfst { namespace implementations {
           }
         }
       }
-      
+
       /* Handle spv here. Special symbols (flags, epsilons)
          are always inserted. */
 
       std::string istring("");
       std::string ostring("");
-    
+
       //find the key in sigma
       char* c_in=NULL;
       for(struct sigma* sig=t->sigma; sig!=NULL&&sig->symbol!=NULL;
@@ -659,13 +667,13 @@ namespace hfst { namespace implementations {
       if(added_fd_state)
         fd_state_stack->pop_back();
     }
-    
+
     path_visitations[state]--;
     return res;
   }
-  
+
   static const int BUFFER_START_SIZE = 64;
-  
+
   void FomaTransducer::extract_paths
   (fsm * t, ExtractStringsCb& callback,
    int cycles, FdTable<int>* fd, bool filter_fd)
@@ -677,7 +685,7 @@ namespace hfst { namespace implementations {
       (1, hfst::FdState<int>(*fd));
 
     std::set<int> initial_states;
-    
+
     StringPairVector spv;
     bool res = true;
     for (int i=0; ((t->states)+i)->state_no != -1 && res == true; i++) {
@@ -686,7 +694,7 @@ namespace hfst { namespace implementations {
            == initial_states.end()) ) {
 
         initial_states.insert(((t->states)+i)->state_no);
-                
+
         res = hfst::implementations::extract_paths
           (t, ((t->states)+i)->state_no, all_visitations, path_visitations,
            callback, cycles, fd_state_stack,
@@ -724,7 +732,7 @@ namespace hfst { namespace implementations {
       (void)max_num;
       HFST_THROW(FunctionNotImplementedException);
     }
-  
+
   void FomaTransducer::insert_to_alphabet(fsm * t, const std::string &symbol)
   {
     sigma_add(strdup(symbol.c_str()), t->sigma);
@@ -752,7 +760,7 @@ namespace hfst { namespace implementations {
     alpha.insert(internal_identity);
     return alpha;
   }
-    
+
   unsigned int FomaTransducer::get_symbol_number
   (fsm *t,
    const std::string &symbol)
@@ -836,33 +844,6 @@ namespace hfst { namespace implementations {
     return table;
   }
 
-#if GENERATE_LEXC_WRAPPER
-    fsm * FomaTransducer::read_lexc(const std::string &filename, bool verbose)
-  {
-    char * filename_ = strdup(filename.c_str());
-    char * lexcfile = file_to_mem(filename_);
-    if (lexcfile == NULL)
-      {
-    std::string msg("Could not read file ");
-    msg + filename;
-    HFST_THROW_MESSAGE(StreamNotReadableException, msg);
-      }
-    free(filename_);
-    int verbose_int = 0;
-    if (verbose)
-      verbose_int = 1;
-    fsm * retval = fsm_lexc_parse_string(lexcfile, verbose_int);
-    if (retval == NULL)
-      {
-    std::string msg("Not valid Lexc format in file ");
-    msg + filename;
-    HFST_THROW_MESSAGE(NotValidLexcFormatException, msg);
-      }
-    free(lexcfile);
-    return retval;
-  }
-#endif
-
   fsm * FomaTransducer::eliminate_flags(fsm * t)
   {
     return flag_eliminate(t, NULL);
@@ -888,12 +869,12 @@ namespace hfst { namespace implementations {
 
     /* Read foma transducer . */
     fsm * FomaTransducer::read_net(FILE *infile) {
-      
+
     const unsigned int READ_BUF_SIZE=4096;
     char buf[READ_BUF_SIZE];
     fsm *net;
     struct fsm_state * fsm_;
-    
+
     char *new_symbol;
     int i, items, new_symbol_number, laststate, lineint[5], *cm;
     char last_final = 0;
@@ -901,11 +882,11 @@ namespace hfst { namespace implementations {
     if (io_gets(infile, buf) == 0) {
         return NULL;
     }
-    
+
     char* empty = strdup("");
     net = fsm_create(empty);
     free(empty);
-    
+
     if (strcmp(buf, "##foma-net 1.0##") != 0) {
         printf("File format error foma!\n");
         return NULL;
@@ -942,7 +923,6 @@ namespace hfst { namespace implementations {
         printf("File format error sigma!\n");
         return NULL;
     }
-    net->sigma = sigma_create();
     for (;;) {
       io_gets(infile, buf);
         if (buf[0] == '#') break;
@@ -1103,7 +1083,7 @@ static inline int explode_line (char *buf, int *values) {
             net->is_loop_free,
             net->is_completed,
             net->name);
-    
+
     /* Sigma */
     fprintf(outfile, "%s","##sigma##\n");
     for (sigma = net->sigma; sigma != NULL && sigma->number != -1;
@@ -1185,7 +1165,7 @@ int main(int argc, char * argv[])
     fsm * a = FomaTransducer::define_transducer("a");
     fsm * a2 = FomaTransducer::repeat_n(a, 2);
     (void)a2;
-    
+
     std::cout << std::endl << "ok" << std::endl;
     return EXIT_SUCCESS;
 #else // HAVE_FOMA
