@@ -16,7 +16,11 @@
 #ifdef _MSC_VER
 #include "back-ends/openfstwin/src/include/fst/fstlib.h"
 #else
+#if HAVE_OPENFST_UPSTREAM
+#include <fst/fstlib.h>
+#else
 #include "back-ends/openfst/src/include/fst/fstlib.h"
+#endif
 #endif // _MSC_VER
 
 #if defined(USE_FOMA_EPSILON_REMOVAL) && defined(HAVE_FOMA)
@@ -64,7 +68,7 @@ namespace hfst {
     {
       warning_stream = os;
     }
- 
+
     // This function can be moved to its own file if TropicalWeightTransducer.o
     // yields a 'File too big' error.
     StdVectorFst * TropicalWeightTransducer::push_labels
@@ -73,7 +77,7 @@ namespace hfst {
       assert (t->InputSymbols() != NULL);
 
       CHECK_EPSILON_CYCLES(t, "push_labels");
-      
+
       fst::StdVectorFst * retval = new fst::StdVectorFst();
       if (to_initial_state)
         fst::Push<StdArc, REWEIGHT_TO_INITIAL>(*t, retval, fst::kPushLabels);
@@ -91,7 +95,7 @@ namespace hfst {
       assert (t->InputSymbols() != NULL);
 
       CHECK_EPSILON_CYCLES(t, "push_weights");
-      
+
       fst::StdVectorFst * retval = new fst::StdVectorFst();
       if (to_initial_state)
         fst::Push<StdArc, REWEIGHT_TO_INITIAL>(*t, retval, fst::kPushWeights);
@@ -241,7 +245,7 @@ namespace hfst {
   void initialize_symbol_tables(StdVectorFst *t);
 
   TropicalWeightInputStream::TropicalWeightInputStream(void):
-    i_stream(),input_stream(cin)
+    i_stream(),input_stream(std::cin)
   {}
 
   TropicalWeightInputStream::TropicalWeightInputStream
@@ -322,7 +326,7 @@ namespace hfst {
         }
       }
   }
-  
+
   StringSet TropicalWeightTransducer::get_initial_input_symbols(StdVectorFst *t)
   {
     assert(t->InputSymbols() != NULL);
@@ -367,6 +371,10 @@ namespace hfst {
   {
     assert(t->InputSymbols() != NULL);
     StringSet symbols;
+    if (t->NumStates() == 0)
+    {
+      return symbols;
+    }
     StateId s = t->Start();
     std::set<StateId> visited_states;
     get_first_input_symbols(t, s, visited_states, symbols);
@@ -440,11 +448,11 @@ namespace hfst {
           ! it.Done(); it.Next() ) {
       km [ (unsigned int)it.Value() ]
         = (unsigned int) t2->InputSymbols()->Find( it.Symbol() );
-      
+
       assert(it.Value() >= 0);
       assert(! (t2->InputSymbols()->Find( it.Symbol() ) < 0));
     }
-    
+
     return km;
   }
 
@@ -552,7 +560,7 @@ namespace hfst {
     if (initial_state != 0) {
       zero_print = initial_state;
     }
-      
+
     for (fst::StateIterator<StdVectorFst> siter(*t);
          ! siter.Done(); siter.Next())
       {
@@ -635,7 +643,7 @@ namespace hfst {
     if (initial_state != 0) {
       zero_print = initial_state;
     }
-      
+
     for (fst::StateIterator<StdVectorFst> siter(*t);
          ! siter.Done(); siter.Next())
       {
@@ -719,7 +727,7 @@ namespace hfst {
     if (initial_state != 0) {
       zero_print = initial_state;
     }
-      
+
     for (fst::StateIterator<StdVectorFst> siter(*t);
          ! siter.Done(); siter.Next())
       {
@@ -805,7 +813,7 @@ namespace hfst {
     if (initial_state != 0) {
       zero_print = initial_state;
     }
-      
+
     for (fst::StateIterator<StdVectorFst> siter(*t);
          ! siter.Done(); siter.Next())
       {
@@ -877,7 +885,7 @@ namespace hfst {
         }
       }
   }
-  
+
 
   // AT&T format is handled here ------------------------------
 
@@ -1030,7 +1038,7 @@ namespace hfst {
                      it1 != unknown.end(); it1++)
                   {
             if (! FdOperation::is_diacritic(*it1)) {
-              
+
               int64 inumber = is->Find(*it1);
               for (StringSet::iterator it2 = unknown.begin();
                it2 != unknown.end(); it2++)
@@ -1112,7 +1120,7 @@ namespace hfst {
     for (fst::StateIterator<StdVectorFst> siter(*t);
          ! siter.Done(); siter.Next())
       result->AddState();
-    
+
     // go through all states in this
     for (fst::StateIterator<StdVectorFst> siter(*t);
          ! siter.Done(); siter.Next())
@@ -1128,7 +1136,7 @@ namespace hfst {
         // make the new state final, if needed
         if (t->Final(s) != TropicalWeight::Zero())
           result->SetFinal(result_s, t->Final(s).Value());
-        
+
 
         // go through all the arcs in this
         for (fst::ArcIterator<StdVectorFst> aiter(*t,s);
@@ -1139,7 +1147,7 @@ namespace hfst {
             // find the corresponding target state in result or, if not found,
             // create a new state
             StateId result_nextstate=arc.nextstate;
-            
+
             // copy the transition
             result->AddArc(result_s, StdArc(arc.ilabel, arc.olabel,
                                             arc.weight, result_nextstate));
@@ -1184,7 +1192,7 @@ namespace hfst {
     StringSet t2_symbols = get_alphabet(t2);
     hfst::symbols::collect_unknown_sets(t1_symbols, unknown_t1,
                     t2_symbols, unknown_t2);
-    
+
     if (DEBUG)
       {
     fprintf(stderr, "New symbols for t1: ");
@@ -1212,7 +1220,7 @@ namespace hfst {
       }
     }
     t2->SetInputSymbols(st2);
-    
+
     // ...calculate the number mappings needed in harmonization...
     NumberNumberMap km = create_mapping(t1, t2);
 
@@ -1226,7 +1234,7 @@ namespace hfst {
 
     // 3. Calculate the set of symbol pairs to which a non-identity "?:?"
     //    transition is expanded for both transducers.
-    
+
     fst::StdVectorFst *harmonized_t1;
     fst::StdVectorFst *harmonized_t2;
 
@@ -1260,7 +1268,7 @@ namespace hfst {
     input_stream.ignore(6);
     skip_identifier_version_3_0();
   }
-  
+
   void TropicalWeightInputStream::close(void)
   {
     if (filename != string())
@@ -1272,7 +1280,7 @@ namespace hfst {
   }
   bool TropicalWeightInputStream::is_bad(void) const
   {
-    if (filename == string())
+    if (filename.empty())
       { return std::cin.bad(); }
     else
       { return input_stream.bad(); }
@@ -1281,17 +1289,17 @@ namespace hfst {
   {
     if(is_eof())
       return false;
-    if (filename == string())
+    if (filename.empty())
       { return std::cin.good(); }
     else
       { return input_stream.good(); }
   }
-  
+
   bool TropicalWeightInputStream::is_fst(void) const
   {
     return is_fst(input_stream);
   }
-  
+
   bool TropicalWeightInputStream::is_fst(FILE * f)
   {
     if (f == NULL)
@@ -1300,8 +1308,8 @@ namespace hfst {
     ungetc(c, f);
     return c == 0xd6;
   }
-  
-  bool TropicalWeightInputStream::is_fst(istream &s)
+
+  bool TropicalWeightInputStream::is_fst(std::istream &s)
   {
     return s.good() && (s.peek() == 0xd6);
   }
@@ -1321,7 +1329,7 @@ namespace hfst {
     FstHeader header;
     try
       {
-        if (filename == string())
+        if (filename.empty())
           {
             header.Read(input_stream,"STDIN");
             t = static_cast<StdVectorFst*>
@@ -1440,7 +1448,7 @@ namespace hfst {
     st.AddSymbol(internal_identity, 2);
     return st;
   }
-  
+
   void TropicalWeightTransducer::initialize_symbol_tables(StdVectorFst *t) {
     SymbolTable st = create_symbol_table("");
     t->SetInputSymbols(&st);
@@ -1500,7 +1508,7 @@ namespace hfst {
   (const std::string &symbol)
   {
 
-    assert(! (symbol == ""));
+    assert(! (symbol.empty()));
 
     StdVectorFst * t = new StdVectorFst;
     SymbolTable st = create_symbol_table("");
@@ -1519,8 +1527,8 @@ namespace hfst {
     (const std::string &isymbol, const std::string &osymbol)
   {
 
-    assert(! (isymbol == ""));
-    assert(! (osymbol == ""));
+    assert(! (isymbol.empty()));
+    assert(! (osymbol.empty()));
 
     StdVectorFst * t = new StdVectorFst;
     SymbolTable st = create_symbol_table("");
@@ -1569,7 +1577,7 @@ namespace hfst {
 
     return retval;
   }
-  
+
   bool TropicalWeightTransducer::is_automaton(StdVectorFst * t)
   {
     for (fst::StateIterator<StdVectorFst> siter(*t);
@@ -1609,8 +1617,8 @@ namespace hfst {
       {
         StateId s2 = t->AddState();
 
-    assert(! (it->first == ""));
-    assert(! (it->second == ""));
+    assert(! (it->first.empty()));
+    assert(! (it->second.empty()));
 
         t->AddArc(s1,StdArc(st.AddSymbol(it->first),
                             st.AddSymbol(it->second),0,s2));
@@ -1638,8 +1646,8 @@ namespace hfst {
            it != sps.end();
            ++it)
         {
-      assert(! (it->first == ""));
-      assert(! (it->second == ""));
+      assert(! (it->first.empty()));
+      assert(! (it->second.empty()));
 
           t->AddArc(s1,StdArc(st.AddSymbol(it->first),
                               st.AddSymbol(it->second),0,s2));
@@ -1666,8 +1674,8 @@ namespace hfst {
         for (StringPairSet::const_iterator it2 = (*it).begin();
              it2 != (*it).end(); it2++ ) {
 
-      assert(! (it2->first == ""));
-      assert(! (it2->second == ""));
+      assert(! (it2->first.empty()));
+      assert(! (it2->second.empty()));
 
           t->AddArc(s1,StdArc(st.AddSymbol(it2->first),
                               st.AddSymbol(it2->second),0,s2));
@@ -1836,7 +1844,7 @@ namespace hfst {
     t->SetFinal(state, 0.5);
     t->AddArc(initial, StdArc(1,1,0.5,state));
     t->AddArc(state, StdArc(2,2,0.5,initial));
- 
+
     // print t before minimize
     print_att_number(t, stderr);
 
@@ -2050,7 +2058,7 @@ namespace hfst {
     retval->SetInputSymbols(t->InputSymbols());
     return retval;
   }
-  
+
   typedef std::pair<int,int> LabelPair;
   typedef std::vector<LabelPair> LabelPairVector;
 
@@ -2079,7 +2087,7 @@ namespace hfst {
     RelabelFst<StdArc> t_subst(*t,v,v);
     return new StdVectorFst(t_subst);
   }
-  
+
   void TropicalWeightTransducer::set_symbol_table
   (StdVectorFst * t,
    std::vector<std::pair<unsigned short, std::string> > symbol_mappings)
@@ -2190,10 +2198,10 @@ namespace hfst {
     assert(t->InputSymbols() != NULL);
     SymbolTable * st = t->InputSymbols()->Copy();
     // TODO: cl.exe: conversion from 'int64' to 'unsigned int'
-    pair<unsigned int, unsigned int> old_pair
+    std::pair<unsigned int, unsigned int> old_pair
       ((unsigned int)st->AddSymbol(old_symbol_pair.first),
        (unsigned int)st->AddSymbol(old_symbol_pair.second));
-    pair<unsigned int, unsigned int> new_pair
+    std::pair<unsigned int, unsigned int> new_pair
       ((unsigned int)st->AddSymbol(new_symbol_pair.first),
        (unsigned int)st->AddSymbol(new_symbol_pair.second));
     StdVectorFst * retval = substitute(t, old_pair, new_pair);
@@ -2365,7 +2373,7 @@ namespace hfst {
                                       tr_arc.nextstate + start_state
                                       )
                          );
-              
+
             }
           }
         }
@@ -2450,7 +2458,7 @@ namespace hfst {
       }
 
     t->SetFinal(s,0);
-    
+
     t->SetInputSymbols(st);
     return t;
   }
@@ -2607,7 +2615,7 @@ namespace hfst {
       }
     return t_copy;
   }
-  
+
 
   // ----- TRIE FUNCTIONS BEGINS -----
 
@@ -2669,7 +2677,7 @@ namespace hfst {
           }
       }
   }
-  
+
   void TropicalWeightTransducer::add_sub_trie(fst::StdVectorFst &t1,
                   StateId t1_state,
                   const fst::StdVectorFst * t2,
@@ -2725,9 +2733,9 @@ namespace hfst {
             return ret.continueSearch;
           }
       }
-    
+
     // sort arcs by number of visitations
-    vector<const StdArc*> arcs;
+    std::vector<const StdArc*> arcs;
     for(fst::ArcIterator<StdVectorFst> it(*t,s); !it.Done(); it.Next())
     {
       const StdArc& a = it.Value();
@@ -2740,13 +2748,13 @@ namespace hfst {
         arcs[k] = arcs[k-1];
       arcs[i] = &a;
     }
-    
+
     bool res = true;
     for( size_t i=0; i<arcs.size() && res == true; i++ )
     {
       const StdArc &arc = *(arcs[i]);
       bool added_fd_state = false;
-    
+
       if (fd_state_stack) {
         if(fd_state_stack->back().get_table().get_operation(arc.ilabel)
            != NULL) {
@@ -2759,7 +2767,7 @@ namespace hfst {
           }
         }
       }
-      
+
       /* Handle spv here. Special symbols (flags, epsilons)
          are always inserted. */
 
@@ -2782,32 +2790,32 @@ namespace hfst {
          weight_sum+arc.weight.Value(),
          callback, cycles, fd_state_stack, filter_fd,
          spv);
-      
+
       spv.pop_back();
 
       if(added_fd_state)
         fd_state_stack->pop_back();
     }
-    
+
     path_visitations[s]--;
     return res;
   }
-  
+
   static const int BUFFER_START_SIZE = 64;
-  
+
   void TropicalWeightTransducer::extract_paths
   (StdVectorFst * t, hfst::ExtractStringsCb& callback,
    int cycles, FdTable<int64>* fd, bool filter_fd)
   {
     if (t->Start() == -1)
       return;
-    
-    map<StateId, unsigned short> all_visitations;
-    map<StateId, unsigned short> path_visitations;
+
+    std::map<StateId, unsigned short> all_visitations;
+    std::map<StateId, unsigned short> path_visitations;
     std::vector<hfst::FdState<int64> >* fd_state_stack
       = (fd==NULL) ? NULL : new std::vector<hfst::FdState<int64> >
       (1, hfst::FdState<int64>(*fd));
-    
+
     StringPairVector spv;
     hfst::implementations::extract_paths
       (t,t->Start(),all_visitations,path_visitations,
@@ -2829,7 +2837,7 @@ namespace hfst {
     int start_state = t->Start();
     if (start_state < 0)
       return true;
-    
+
     for (fst::ArcIterator<StdVectorFst> aiter(*t,start_state);
          !aiter.Done(); aiter.Next())
       {
@@ -2845,7 +2853,7 @@ namespace hfst {
     if (is_minimal_and_empty(t)) {
       throw "transducer is empty";
     }
-    
+
     HfstTwoLevelPath path;
     path.first=0; // zero weight
     StateId current_state = t->Start();
@@ -2878,15 +2886,15 @@ namespace hfst {
     while (1) {
 
       visited[ current_state ] = 1;
-      
-      vector<fst::StdArc> t_transitions;
+
+      std::vector<fst::StdArc> t_transitions;
 
       for (fst::ArcIterator<StdVectorFst> aiter(*t,current_state);
        !aiter.Done(); aiter.Next())
     {
       t_transitions.push_back(aiter.Value());
     }
-      
+
       /* If we cannot proceed, return the longest path so far. */
       if (t_transitions.empty() || broken[current_state]) {
         for (int i=(int)path.second.size()-1; i>=last_index; i--) {
@@ -2903,7 +2911,7 @@ namespace hfst {
     unsigned int index = rand() % t_transitions.size();
     fst::StdArc arc = t_transitions.at(index);
     t_transitions.erase(t_transitions.begin()+index);
-    
+
     StateId t_target = arc.nextstate;
 
     path.second.push_back
@@ -2929,7 +2937,7 @@ namespace hfst {
         if ( (rand() % 4) == 0 )
           broken[ t_target ] = 1;
     }
-    
+
     if ( visited[ t_target ] == 1 ) {
       if ( (rand() % 4) == 0 )
         broken[ t_target ] = 1;
@@ -2998,7 +3006,7 @@ namespace hfst {
       {
         HfstTwoLevelPath path = *it;
         StringVector sv = hfst::symbols::to_string_vector(path);
-        
+
         if (fdt.is_valid_string(sv))
           {
             if (filter_fd)
@@ -3036,7 +3044,7 @@ namespace hfst {
               }
             return; // not even possible to extract paths
           }
-        
+
         /* If we extract the same path again, try at most 5 times
            to extract another one. */
         unsigned int i = max_num;
@@ -3054,7 +3062,7 @@ namespace hfst {
         /* Insert the path (another or the same). */
         results.insert(path);
       }
-    
+
     return;
   }
 
