@@ -13,8 +13,8 @@
 #include "transducer.h"
 #include "pmatch.h"
 
-#ifdef OPENFST_VERSION_1_5_4
-  #include "back-ends/openfst/src/include/fst/fst-decl.h"
+#ifdef HAVE_OPENFST_UPSTREAM
+  #include <fst/fst-decl.h>
   namespace fst { template <class F> class ArcIterator; }
 #endif
 
