@@ -6,6 +6,7 @@
 // version 3 of the License, or (at your option) any later version.
 // See the file COPYING included with this distribution for more
 // information.
+
 #include "pmatch.h"
 #include "hfst.h"
 
@@ -45,7 +46,7 @@ PmatchAlphabet::PmatchAlphabet(std::istream & inputstream,
                     std::string feature =  hfst::FdOperation::get_feature(symbol_table[i])
                         .substr(14, std::string::npos);
                     std::string value = hfst::FdOperation::get_value(symbol_table[i]);
-                    std::string new_diacritic = s.substr(0, 3) + feature + (value == "" ? "" : "." + value) + "@";
+                    std::string new_diacritic = s.substr(0, 3) + feature + (value.empty() ? "" : "." + value) + "@";
                     fd_table.define_diacritic(i, new_diacritic);
                     // finally go over all other known flag diacritics with the non-globalized feature and
                     // mark them global too
@@ -84,7 +85,8 @@ PmatchAlphabet::PmatchAlphabet(TransducerAlphabet const & a,
 }
 
 PmatchAlphabet::PmatchAlphabet(void):
-    TransducerAlphabet()
+    TransducerAlphabet(),
+    container(0)
 {}
 
 void PmatchAlphabet::add_symbol(const std::string & symbol)
@@ -100,15 +102,9 @@ void PmatchAlphabet::add_symbol(const std::string & symbol)
         symbol2lists[symbol_table.size()] = hfst::size_t_to_ushort(symbol_lists.size());
         symbol_lists.push_back(SymbolNumberVector(exclusionary_lists.begin(),
                                                   exclusionary_lists.end()));
-#if defined(_MSC_VER) || defined(NO_CPLUSPLUS_11)
-        for (SymbolNumberVector::const_iterator exc = exclusionary_lists.begin(); exc != exclusionary_lists.end(); exc++) {
-          symbol_list_members[list2symbols[*exc]].push_back(hfst::size_t_to_uint(symbol_table.size()));
-        }
-#else
 	for(const auto & exc: exclusionary_lists) {
           symbol_list_members[list2symbols[exc]].push_back(symbol_table.size());
         }
-#endif
     }
     TransducerAlphabet::add_symbol(symbol);
 }
@@ -145,6 +141,14 @@ void PmatchAlphabet::add_special_symbol(const std::string & str,
         special_symbols[Pmatch_passthrough] = symbol_number;
     } else if (str == "@BOUNDARY@") {
         special_symbols[boundary] = symbol_number;
+    } else if (str == "@UNICODE_ALPHA@") {
+        special_symbols[UnicodeAlpha] = symbol_number;
+    } else if (str == "@UNICODE_UPPERALPHA@") {
+        special_symbols[UnicodeUpperAlpha] = symbol_number;
+    } else if (str == "@UNICODE_LOWERALPHA@") {
+        special_symbols[UnicodeLowerAlpha] = symbol_number;
+    } else if (str == "@UNICODE_WHITESPACE@") {
+        special_symbols[UnicodeWhitespace] = symbol_number;
     } else if (is_end_tag(str)) {
         // Fetch the part between @PMATCH_ENDTAG_ and @
         end_tag_map[symbol_number] = str.substr(
@@ -237,10 +241,11 @@ void PmatchAlphabet::process_underscored_symbol_list(const std::string & str, Sy
                 find(list_symbols.begin(), list_symbols.end(), candidate_for_list) == list_symbols.end()) {
                 excl_symbols.push_back(candidate_for_list);
                 if (symbol2lists[candidate_for_list] == NO_SYMBOL_NUMBER) {
+                    // This symbol is not yet associated with any list
                   symbol2lists[candidate_for_list] = hfst::size_t_to_ushort(symbol_lists.size());
                     symbol_lists.push_back(SymbolNumberVector(1, sym));
                 } else {
-                    symbol_lists[symbol2lists[sym]].push_back(sym);
+                    symbol_lists[symbol2lists[candidate_for_list]].push_back(sym);
                 }
             }
         }
@@ -360,7 +365,7 @@ PmatchContainer::PmatchContainer(std::istream & inputstream):
     if (properties.count("initial-symbols") == 1) {
         collect_first_symbols(properties["initial-symbols"]);
     }
-    
+
     toplevel = new hfst_ol::PmatchTransducer(
         inputstream,
         header.index_table_size(),
@@ -375,21 +380,31 @@ PmatchContainer::PmatchContainer(std::istream & inputstream):
         } catch (TransducerHeaderException & e) {
           (void)e; break;
         }
-        header = TransducerHeader(inputstream);
-        TransducerAlphabet dummy = TransducerAlphabet(
-            inputstream, header.symbol_count());
-        hfst_ol::PmatchTransducer * rtn =
-            new hfst_ol::PmatchTransducer(inputstream,
+        if (transducer_name.rfind("UNCOMPOSE LEFT", 0) == 0) {
+            uncompose_left = new Transducer(inputstream);
+            uncomposable = true;
+        }
+        else if (transducer_name.rfind("UNCOMPOSE RIGHT", 0) == 0) {
+            uncompose_right = new Transducer(inputstream);
+            uncomposable = true;
+        } else
+          {
+            header = TransducerHeader(inputstream);
+            TransducerAlphabet::fake_read_alphabet(
+                inputstream, header.symbol_count());
+            hfst_ol::PmatchTransducer * rtn =
+                new hfst_ol::PmatchTransducer(inputstream,
                                           header.index_table_size(),
                                           header.target_table_size(),
                                           alphabet,
                                           transducer_name,
                                           this);
-        if (!alphabet.has_rtn(transducer_name)) {
-            alphabet.add_rtn(rtn, transducer_name);
-        } else {
-            delete rtn;
-        }
+            if (!alphabet.has_rtn(transducer_name)) {
+                alphabet.add_rtn(rtn, transducer_name);
+            } else {
+                delete rtn;
+            }
+          }
     }
 }
 
@@ -645,12 +660,12 @@ bool PmatchAlphabet::is_counter(const std::string & symbol)
 
 bool PmatchAlphabet::is_list(const std::string & symbol)
 {
-    return (symbol.find("@L.") == 0 || symbol.find("@X.") == 0) && symbol.rfind("@") == symbol.size() - 1;
+    return (symbol.find("@L.") == 0 || symbol.find("@X.") == 0) && symbol.rfind("@") == symbol.size() - 1 && symbol.size() > 4;
 }
 
 bool PmatchAlphabet::is_underscored_list(const std::string & symbol)
 {
-    return (symbol.find("@L.") == 0 || symbol.find("@X.") == 0) && symbol.rfind("_@") == symbol.size() - 2;
+    return (symbol.find("@L.") == 0 || symbol.find("@X.") == 0) && symbol.rfind("_@") == symbol.size() - 2 && symbol.size() > 5;
 }
 
 bool PmatchAlphabet::is_global_flag(const std::string & symbol)
@@ -672,8 +687,8 @@ bool PmatchAlphabet::is_special(const std::string & symbol)
     if (symbol == "@PMATCH_INPUT_MARK@" || symbol == "@PMATCH_BACKTRACK@") { // seems like is_special symbols can't be referred to in pmatch scripts
         return false;
     }
-    if (is_insertion(symbol) || symbol == "@BOUNDARY@") {
-//        || symbol == "@_UNKNOWN_SYMBOL_@" || symbol == "@_IDENTITY_SYMBOL_@"
+    if (is_insertion(symbol) || symbol == "@BOUNDARY@" || symbol == "@UNICODE_ALPHA@"
+        || symbol == "@UNICODE_UPPERALPHA@" || symbol == "@UNICODE_LOWERALPHA@" || symbol == "@UNICODE_WHITESPACE@") {
         return true;
     } else {
         return (symbol.find("@PMATCH") == 0 && symbol.at(symbol.size() - 1) == '@')
@@ -710,6 +725,15 @@ bool PmatchAlphabet::is_input_mark(const SymbolNumber symbol) const
     return input_mark_symbol == symbol;
 }
 
+bool PmatchAlphabet::is_meta_arc(const SymbolNumber symbol) const
+{
+    return TransducerAlphabet::is_meta_arc(symbol) ||
+        symbol == get_special(UnicodeAlpha) ||
+        symbol == get_special(UnicodeUpperAlpha) ||
+        symbol == get_special(UnicodeLowerAlpha) ||
+        symbol == get_special(UnicodeWhitespace);
+}
+
 std::string PmatchAlphabet::name_from_insertion(const std::string & symbol)
 {
     return symbol.substr(sizeof("@I.") - 1, symbol.size() - (sizeof("@I.@") - 1));
@@ -731,7 +755,7 @@ std::string PmatchAlphabet::start_tag(const SymbolNumber symbol)
     } else {
         return "<" + end_tag_map[symbol] + ">";
     }
-    
+
 }
 
 PmatchContainer::~PmatchContainer(void)
@@ -836,18 +860,8 @@ bool PmatchAlphabet::has_rtn(std::string const & name) const
     if (name == "TOP") {
         return true;
     }
-#ifdef NO_CPLUSPLUS_11
-    hfst_ol::RtnNameMap::const_iterator it = rtn_names.find(name);
-    if (it != rtn_names.end())
-    {
-        return it->second < rtns.size() && rtns[it->second] != NULL;
-    } else {
-        return false;
-    }
-#else	
     return rtn_names.count(name) != 0 &&
         rtn_names.at(name) < rtns.size() && rtns[rtn_names.at(name)] != NULL;
-#endif
 }
 
 bool PmatchAlphabet::has_rtn(SymbolNumber symbol) const
@@ -934,8 +948,8 @@ void PmatchContainer::process(const std::string & input_str)
                 LocationVector ls;
                 for (WeightedDoubleTapeVector::iterator it = tape_locations.begin();
                      it != tape_locations.end(); ++it) {
-                    ls.push_back(alphabet.locatefy(printable_input_pos,
-                                                   *it));
+                    Location l = alphabet.locatefy(printable_input_pos, *it);
+                    ls.push_back(l);
                 }
                 sort(ls.begin(), ls.end());
                 locations.push_back(ls);
@@ -1215,8 +1229,8 @@ PmatchTransducer::PmatchTransducer(std::istream & is,
                                    PmatchAlphabet & alpha,
                                    std::string _name,
                                    PmatchContainer * cont):
-    alphabet(alpha),
     name(_name),
+    alphabet(alpha),
     container(cont)
 {
     orig_symbol_count = hfst::size_t_to_uint(alphabet.get_symbol_table().size());
@@ -1260,10 +1274,10 @@ PmatchTransducer::PmatchTransducer(std::vector<TransitionW> transition_vector,
                                    PmatchAlphabet & alpha,
                                    std::string _name,
                                    PmatchContainer * cont):
+    name(_name),
     transition_table(transition_vector),
     index_table(index_vector),
     alphabet(alpha),
-    name(_name),
     container(cont)
 {
     orig_symbol_count = hfst::size_t_to_uint(alphabet.get_symbol_table().size());
@@ -1291,6 +1305,7 @@ void PmatchContainer::set_properties(void)
     max_recursion = 5000;
     need_separators = true;
     xerox_composition = true;
+    uncomposable = false;
 }
 
 void PmatchContainer::set_properties(std::map<std::string, std::string> & properties)
@@ -1583,7 +1598,7 @@ void PmatchTransducer::take_epsilons(unsigned int input_pos,
         if (input != 0 && !alphabet.is_flag_diacritic(input) && !alphabet.has_rtn(input)) {
             return;
         }
-        
+
         SymbolNumber output = transition_table[i].get_output_symbol();
         TransitionTableIndex target = transition_table[i].get_target();
         Weight old_weight = container->get_weight();
@@ -1614,12 +1629,14 @@ void PmatchTransducer::take_epsilons(unsigned int input_pos,
             if (!try_entering_context(output)) {
                 // no context to enter, regular input epsilon
                 container->tape.write(tape_pos, 0, output);
-                
+
+                unsigned int orig_entry_stack_back;
                 // if it's an entry or exit arc, adjust entry stack
                 if (output == alphabet.get_special(entry)) {
-                    container->entry_stack.push(input_pos);
+                    container->entry_stack.push_back(input_pos);
                 } else if (output == alphabet.get_special(exit)) {
-                    container->entry_stack.pop();
+                    orig_entry_stack_back = container->entry_stack.back();
+                    container->entry_stack.pop_back();
                 } else if (alphabet.is_capture_tag(output)) {
                     // if it's a capture tag, remember where we were
                     Capture capture;
@@ -1632,6 +1649,7 @@ void PmatchTransducer::take_epsilons(unsigned int input_pos,
                     // captured sequence
                     std::pair<SymbolNumberVector::iterator, SymbolNumberVector::iterator> cap =
                         container->get_longest_matching_capture(alphabet.captured2capture[output], input_pos);
+
                     if (cap.second - cap.first != 0) {
                         container->tape.write(tape_pos, cap);
                         get_analyses(input_pos + (cap.second - cap.first),
@@ -1641,13 +1659,13 @@ void PmatchTransducer::take_epsilons(unsigned int input_pos,
                     container->set_weight(old_weight);
                     continue;
                 }
-                
+
                 get_analyses(input_pos, tape_pos + 1, target);
-                
+
                 if (output == alphabet.get_special(entry)) {
                     container->entry_stack.pop_back();
                 } else if (output == alphabet.get_special(exit)) {
-                    container->entry_stack.unpop();
+                    container->entry_stack.push_back(orig_entry_stack_back);
                 } else if (alphabet.is_capture_tag(output)) {
                     container->captures.pop_back();
                 }
@@ -1675,7 +1693,7 @@ void PmatchTransducer::check_context(unsigned int input_pos,
     if (local_stack.top().context == LC ||
         local_stack.top().context == NLC) {
         // Jump to the left-hand side of the input
-        input_pos = container->entry_stack.top() - 1;
+        input_pos = container->entry_stack.back() - 1;
     }
     get_analyses(input_pos, tape_pos, transition_table[i].get_target());
 
@@ -1727,7 +1745,7 @@ void PmatchTransducer::take_transitions(SymbolNumber input,
                                         TransitionTableIndex i)
 {
     i = make_transition_table_index(i, input);
-    
+
     while (is_good(i)) {
         SymbolNumber this_input = transition_table[i].get_input_symbol();
         SymbolNumber this_output = transition_table[i].get_output_symbol();
@@ -1754,9 +1772,14 @@ void PmatchTransducer::take_transitions(SymbolNumber input,
             } else {
                 // Checking context so don't touch output
                 if (local_stack.top().max_context_length_remaining > 0) {
-                    local_stack.top().max_context_length_remaining -= 1;
-                    get_analyses(input_pos + local_stack.top().tape_step, tape_pos, target);
-                    local_stack.top().max_context_length_remaining += 1;
+                    if ((local_stack.top().tape_step < 0 ) && (input_pos == 0)) {
+                        // FIXME: prevents segfault but
+                        get_analyses(input_pos, tape_pos, target); // awkward
+                    } else {
+                        local_stack.top().max_context_length_remaining -= 1;
+                        get_analyses(input_pos + local_stack.top().tape_step, tape_pos, target);
+                        local_stack.top().max_context_length_remaining += 1;
+                    }
                 }
             }
             local_stack.top().default_symbol_trap = false;
@@ -1806,7 +1829,7 @@ void PmatchTransducer::get_analyses(unsigned int input_pos,
         handle_final_state(input_pos, tape_pos);
         container->set_weight(old_weight);
     }
-    
+
     SymbolNumber input;
     if (!container->has_queued_input(input_pos)) {
         container->unrecurse();
@@ -1823,6 +1846,27 @@ void PmatchTransducer::get_analyses(unsigned int input_pos,
             take_transitions(*it, input_pos, tape_pos, i+1);
         }
     }
+    if (alphabet.get_special(UnicodeAlpha) != NO_SYMBOL_NUMBER) {
+        if (alphabet.is_unicode_alpha(input)) {
+                take_transitions(alphabet.get_special(UnicodeAlpha), input_pos, tape_pos, i+1);
+            }
+    }
+    if (alphabet.get_special(UnicodeUpperAlpha) != NO_SYMBOL_NUMBER) {
+        if (alphabet.is_unicode_upperalpha(input)) {
+                take_transitions(alphabet.get_special(UnicodeUpperAlpha), input_pos, tape_pos, i+1);
+            }
+    }
+    if (alphabet.get_special(UnicodeLowerAlpha) != NO_SYMBOL_NUMBER) {
+        if (alphabet.is_unicode_loweralpha(input)) {
+                take_transitions(alphabet.get_special(UnicodeLowerAlpha), input_pos, tape_pos, i+1);
+            }
+    }
+    if (alphabet.get_special(UnicodeWhitespace) != NO_SYMBOL_NUMBER) {
+        if (alphabet.is_unicode_whitespace(input)) {
+                take_transitions(alphabet.get_special(UnicodeWhitespace), input_pos, tape_pos, i+1);
+            }
+    }
+
     // The "normal" case where we have a regular input symbol
     if (input < orig_symbol_count) {
         take_transitions(input, input_pos, tape_pos, i+1);
@@ -1916,4 +1960,47 @@ void PmatchTransducer::exit_context(void)
     local_stack.push(new_top);
 }
 
-}
+
+void PmatchContainer::uncompose(Location& loc)
+  {
+    if (!uncomposable) {
+        return;
+    }
+    auto middle_left = uncompose_left->lookup_fd(loc.input);
+    if (middle_left->empty()) {
+        // ambig problems
+        return;
+    }
+    std::set<std::string> midforms;
+    for (auto& lpath : *middle_left) {
+        std::stringstream mids;
+        for (auto& symbol : lpath.second) {
+            if (!hfst::FdOperation::is_diacritic(symbol)) {
+                mids << symbol;
+            }
+        }
+        auto middle_right = uncompose_right->lookup_fd(mids.str());
+        if (middle_right->empty()) {
+            continue;
+        }
+        for (auto& rpath : *middle_right) {
+            std::stringstream lows;
+            for (auto& rsym : rpath.second) {
+                if (!hfst::FdOperation::is_diacritic(rsym)) {
+                    lows << rsym;
+                }
+            }
+            if (lows.str() == loc.output) {
+                midforms.insert(mids.str());
+            }
+        }
+    }
+    if (midforms.size() > 1) {
+        // ambig problems
+    }
+    for (auto& form : midforms) {
+        loc.middle = form;
+    }
+  }
+
+};
