@@ -33,8 +33,8 @@ namespace hfst_ol {
     typedef std::vector<Location> LocationVector;
     typedef std::vector<LocationVector> LocationVectorVector;
     typedef std::vector<WeightedDoubleTape> WeightedDoubleTapeVector;
-            
-    
+
+
     enum SpecialSymbol{entry,
                        exit,
                        LC_entry,
@@ -48,22 +48,16 @@ namespace hfst_ol {
                        Pmatch_passthrough,
                        boundary,
                        Pmatch_input_mark,
+                       UnicodeAlpha,
+                       UnicodeUpperAlpha,
+                       UnicodeLowerAlpha,
+                       UnicodeWhitespace,
                        SPECIALSYMBOL_NR_ITEMS};
 
-    class PositionStack: public std::vector<unsigned int>
-    {
-        unsigned int tmp;
-    public:
-        void push(unsigned int val) { push_back(val); }
-        void pop(void) { tmp = back(); pop_back(); }
-        void unpop(void) { push_back(tmp); }
-        unsigned int top(void) { return back(); }
-    };
-
     class PmatchAlphabet: public TransducerAlphabet {
     protected:
         RtnVector rtns;
-        SymbolNumber input_mark_symbol;
+        SymbolNumber input_mark_symbol = 0;
         SymbolNumberVector special_symbols;
         std::map<SymbolNumber, std::string> end_tag_map;
         std::map<std::string, SymbolNumber> capture_tag_map;
@@ -101,7 +95,7 @@ namespace hfst_ol {
         PmatchAlphabet(TransducerAlphabet const & a, PmatchContainer * cont);
         PmatchAlphabet(void);
         ~PmatchAlphabet(void);
-        virtual void add_symbol(const std::string & symbol);
+        void add_symbol(const std::string & symbol) override;
         static bool is_end_tag(const std::string & symbol);
         static bool is_capture_tag(const std::string & symbol);
         static bool is_captured_tag(const std::string & symbol);
@@ -117,6 +111,7 @@ namespace hfst_ol {
             const std::string & symbol);
         bool is_printable(SymbolNumber symbol);
         bool is_global_flag(SymbolNumber symbol);
+        bool is_meta_arc(SymbolNumber symbol) const;
         void add_special_symbol(const std::string & str, SymbolNumber symbol_number);
         void process_underscored_symbol_list(const std::string & str, SymbolNumber sym);
         void process_symbol_list(const std::string & str, SymbolNumber sym);
@@ -161,8 +156,10 @@ namespace hfst_ol {
         PmatchTransducer * toplevel;
         SymbolNumberVector input;
         // This tracks the ENTRY and EXIT tags
-        PositionStack entry_stack;
+        std::vector<unsigned int> entry_stack;
         RtnCallStacks rtn_stacks;
+        hfst_ol::Transducer* uncompose_left;
+        hfst_ol::Transducer* uncompose_right;
         DoubleTape tape;
         DoubleTape best_result;
         DoubleTape result;
@@ -175,7 +172,7 @@ namespace hfst_ol {
         // The flag state for global flags
         hfst::FdState<SymbolNumber> global_flag_state;
         bool verbose;
-        
+
         bool count_patterns;
         bool delete_patterns;
         bool extract_patterns;
@@ -185,6 +182,7 @@ namespace hfst_ol {
         size_t max_recursion;
         bool need_separators;
         bool xerox_composition;
+        bool uncomposable;
 
         unsigned long line_number;
         std::map<std::string, size_t> pattern_counts;
@@ -214,9 +212,9 @@ namespace hfst_ol {
 
     public:
 
-        PmatchContainer(std::istream & is);
-        PmatchContainer(Transducer * toplevel);
-        PmatchContainer(std::vector<hfst::HfstTransducer> transducers);
+        explicit PmatchContainer(std::istream & is);
+        explicit PmatchContainer(Transducer * toplevel);
+        explicit PmatchContainer(std::vector<hfst::HfstTransducer> transducers);
         PmatchContainer(void);
         ~PmatchContainer(void);
 
@@ -311,6 +309,8 @@ namespace hfst_ol {
         void unrecurse(void) { ++recursion_depth_left; }
         void reset_recursion(void) { recursion_depth_left = (unsigned int)max_recursion; }
 
+        void uncompose(Location& loc);
+
         friend class PmatchTransducer;
         friend class PmatchAlphabet;
     };
@@ -320,6 +320,7 @@ namespace hfst_ol {
         unsigned int start;
         unsigned int length;
         std::string input;
+        std::string middle; // composted middle tape
         std::string output;
         std::string tag;
         Weight weight;
@@ -335,7 +336,7 @@ namespace hfst_ol {
     struct ContextMatchedTrap
     {
         bool polarity;
-    ContextMatchedTrap(bool p): polarity(p) {}
+    explicit ContextMatchedTrap(bool p): polarity(p) {}
     };
 
     class PmatchTransducer
@@ -363,7 +364,7 @@ namespace hfst_ol {
         };
 
         std::stack<LocalVariables> local_stack;
-    
+
         std::vector<TransitionW> transition_table;
         std::vector<TransitionWIndex> index_table;
 
@@ -411,12 +412,12 @@ namespace hfst_ol {
         void check_context(unsigned int input_pos,
                            unsigned int tape_pos,
                            TransitionTableIndex i);
-  
+
         void take_flag(SymbolNumber input,
                        unsigned int input_pos,
                        unsigned int tape_pos,
                        TransitionTableIndex i);
-  
+
         void take_transitions(SymbolNumber input,
                               unsigned int input_pos,
                               unsigned int tape_pos,
