@@ -9,13 +9,10 @@
 
 #include "pmatch_tokenize.h"
 
-
-#if USE_ICU_UNICODE
 #include <unicode/unistr.h>
 #include <unicode/brkiter.h>
 static UErrorCode characterBoundaryStatus = U_ZERO_ERROR;
 static icu::BreakIterator* characterBoundary = icu::BreakIterator::createCharacterInstance(NULL, characterBoundaryStatus);
-#endif
 
 namespace hfst_ol_tokenize {
 
@@ -29,6 +26,7 @@ using hfst_ol::LocationVectorVector;
 
 static const string subreading_separator = "#";
 static const string wtag = "W"; // TODO: cg-conv has an argument --wtag, allow changing here as well?
+static bool IS_CG_TAG_MODIFIER_WARNED = false; // Only warn once on skipping modifier letters
 
 void print_escaping_backslashes(std::string const & str, std::ostream & outstream)
 {
@@ -231,17 +229,26 @@ size_t u8_first_codepoint_size(const unsigned char* c) {
  *
  * If we have ICU, we check that the symbol is longer than the first
  * "character" (so characters composed of multiple codepoints are
- * treated the same as their non-composed counterparts).
+ * treated the same as their non-composed counterparts). ICU
+ * doesn't treat modifier letters of as part of the same character,
+ * but we sometimes have them on the same arc – e.g. 'k̓ʷ' where 'ʷ' is
+ * a modifier – so we skip following modifiers too (c.f. issue 497).
  */
 bool is_cg_tag(const string & str) {
-#if USE_ICU_UNICODE
     icu::UnicodeString us(str.c_str());
     characterBoundary->setText(us);
-    return us.length() > characterBoundary->following(0);
-#else
-    // Note: invalid codepoints are also treated as tags;  ¯\_(ツ)_/¯
-    return str.size() > u8_first_codepoint_size((const unsigned char*)str.c_str());
-#endif
+    const int32_t i_after = characterBoundary->following(0);
+    if(u_charType(us.char32At(i_after)) == U_MODIFIER_LETTER) {
+        const bool is_tag = us.length() > characterBoundary->following(i_after);
+        if(!IS_CG_TAG_MODIFIER_WARNED && !is_tag) {
+            std::cerr << "WARNING: Skipping modifier letter for baseform letter " << str << " (to avoid this warning, ensure Modifiers are not part of the same Multichar_symbol as their preceding Character)" << std::endl;
+            IS_CG_TAG_MODIFIER_WARNED = true; // warn only once
+        }
+        return is_tag;
+    }
+    else {
+        return us.length() > i_after;
+    }
 }
 
 void print_cg_subreading(size_t const & indent,
@@ -313,6 +320,78 @@ void print_cg_subreading(size_t const & indent,
     outstream << std::endl;
 }
 
+void print_cg_subreading_ex(size_t const & indent,
+                         hfst::StringVector::const_iterator & out_beg,
+                         hfst::StringVector::const_iterator & out_end,
+                         hfst_ol::Weight const & weight,
+                         hfst::StringVector::const_iterator & in_beg,
+                         hfst::StringVector::const_iterator & in_end,
+                         std::string const & middle,
+                         std::ostream & outstream,
+                         const TokenizeSettings& s)
+{
+    outstream << string(indent, '\t');
+    bool in_lemma = false;
+    for(hfst::StringVector::const_iterator it = out_beg;
+        it != out_end; ++it) {
+        if(it->compare("@PMATCH_BACKTRACK@") == 0) {
+            continue;
+        }
+        bool is_tag = is_cg_tag(*it);
+        if(in_lemma) {
+            if(is_tag) {
+                in_lemma = false;
+                outstream << "\"";
+            }
+        }
+        else {
+            if(!is_tag) {
+                in_lemma = true;
+                outstream << "\"";
+            }
+        }
+        print_escaping_backslashes(*it, outstream);
+    }
+    if(in_lemma) {
+        outstream << "\"";
+    }
+    if ((s.hack_uncompose) && (!middle.empty())) {
+        outstream << " \"" << middle << "\"MIDTAPE";
+    }
+    if (s.print_weights) {
+        std::ostringstream w;
+        w << std::fixed << std::setprecision(9) << weight;
+        std::string rounded = w.str();
+        bool seendot = false;
+        bool inzeroes = true;
+        size_t firstzero = rounded.length();
+        for(size_t i = rounded.length(); i > 0; --i) {
+            if(inzeroes && rounded[i-1] == '0') {
+                firstzero = i;  // not i-1, keep one zero
+            }
+            else {
+                inzeroes = false;
+            }
+            if(rounded[i-1] == '.') {
+                seendot = true;
+                break;
+            }
+        }
+        if(seendot) {
+            rounded = rounded.substr(0, firstzero);
+        }
+        outstream << " <" << wtag << ":" << rounded << ">";
+    }
+    if (in_beg != in_end) {
+        std::ostringstream form;
+        std::copy(in_beg, in_end, std::ostream_iterator<string>(form, ""));
+        outstream << " \"<";
+        print_escaping_backslashes(form.str(), outstream);
+        outstream << ">\"";
+    }
+    outstream << std::endl;
+}
+
 typedef std::set<size_t> SplitPoints;
 
 pair<SplitPoints, size_t>
@@ -325,6 +404,8 @@ print_reading_giellacg(const Location *loc,
     SplitPoints bt_its;
     if(loc->output.empty()) {
         return make_pair(bt_its, indent);
+    } else if ((loc->output.find(" ??") != string::npos) && (indent == 1)) {
+        return make_pair(bt_its, indent);
     }
     typedef hfst::StringVector::const_iterator PartIt;
     PartIt
@@ -338,7 +419,6 @@ print_reading_giellacg(const Location *loc,
     }
     size_t part = loc->input_parts.size();
     while(true) {
-        string inpart;
         bool sub_found = false;
         size_t out_part = part > 0 ? loc->output_parts.at(part-1) : 0;
         while(out_part > 0 && loc->output_symbol_strings.at(out_part-1) == "@PMATCH_BACKTRACK@") {
@@ -372,12 +452,13 @@ print_reading_giellacg(const Location *loc,
                 }
             }
         }
-        print_cg_subreading(indent,
+        print_cg_subreading_ex(indent,
                             out_beg,
                             out_end,
                             loc->weight,
                             in_beg,
                             in_end,
+                            loc->middle,
                             outstream,
                             s);
         if(out_beg == loc->output_symbol_strings.begin()) {
@@ -447,11 +528,15 @@ const LocationVector locate_fullmatch(hfst_ol::PmatchContainer & container,
             continue;
         }
         LocationVector loc = keep_n_best_weight(dedupe_locations(*it, s), s);
-        for (LocationVector::const_iterator loc_it = loc.begin();
+        for (LocationVector::iterator loc_it = loc.begin();
              loc_it != loc.end(); ++loc_it) {
             if(!loc_it->output.empty()
-               && loc_it->weight < std::numeric_limits<float>::max()) {
+               && loc_it->weight < std::numeric_limits<float>::max() &&
+               (loc_it->output.find(" ??") == string::npos)) {
                 // TODO: why aren't the <W:inf> excluded earlier?
+                if (s.hack_uncompose) {
+                    container.uncompose(*loc_it);
+                }
                 loc_filtered.push_back(*loc_it);
             }
         }
@@ -467,8 +552,11 @@ void print_location_vector_giellacg(hfst_ol::PmatchContainer & container,
     outstream << "\"<";
     print_escaping_backslashes(locations.at(0).input, outstream);
     outstream << ">\"" << std::endl;
-    if(locations.size() == 1 && locations.at(0).output.empty()) {
+    if(locations.size() == 1 && (locations.at(0).output.empty() ||
+                                 locations.at(0).output.find(" ??") !=
+                                 string::npos)) {
         // Treat empty analyses as unknown-but-tokenised:
+        // and ??
         outstream << "\t\"";
         print_escaping_backslashes(locations.at(0).input, outstream);
         outstream << "\" ?" << std::endl;
@@ -478,10 +566,16 @@ void print_location_vector_giellacg(hfst_ol::PmatchContainer & container,
     std::set<SplitPoints> backtrack;
     for (LocationVector::const_iterator loc_it = locations.begin();
          loc_it != locations.end(); ++loc_it) {
-        SplitPoints bt_points = print_reading_giellacg(&(*loc_it), 1, false, outstream, s).first;
+        // Check for uncompose
+        Location* hack = new Location(*loc_it);
+                if (s.hack_uncompose) {
+                    container.uncompose(*hack);
+                }
+        SplitPoints bt_points = print_reading_giellacg(hack, 1, false, outstream, s).first;
         if(!bt_points.empty()) {
             backtrack.insert(bt_points);
         }
+        delete hack;
     }
     if(backtrack.empty()) {
 	return;
@@ -552,6 +646,7 @@ void print_location_vector_giellacg(hfst_ol::PmatchContainer & container,
             if(depth == bottom) {
                 for(vector<std::ostringstream>::const_iterator it = out.begin(); it != out.end(); ++it) {
                     outstream << it->str();
+
                 }
             }
             if(depth < bottom) {
