@@ -1,27 +1,24 @@
 import hfst
-from sys import argv
-if len(argv) != 4:
-    raise RuntimeError('Usage: hfst-push-weights.py INFILE -p [input|output]')
+import hfst_commandline
 
-ifile=None
 direction=None
-for arg in argv[1:]:
-    if arg == '-p' or arg == '--push':
-        direction='<next>'
-    elif direction == '<next>':
-        if arg == 'start' or arg == 'initial' or arg == 'begin':
+short_getopts='p:'
+long_getopts=['push=']
+options = hfst_commandline.hfst_getopt(short_getopts, long_getopts, 1)
+
+for opt in options[0]:
+    if opt[0] == '-p' or opt[0] == '--push':
+        if opt[1] == 'start' or opt[1] == 'initial' or opt[1] == 'begin':
             direction = 'start'
-        elif arg == 'end' or arg == 'final':
+        elif opt[1] == 'end' or opt[1] == 'final':
             direction = 'end'
         else:
             raise RuntimeError('hfst-push-weights: push direction must be one of the following [[start|initial|begin]|[end|final]]')
-    else:
-        ifile = arg
 
-if direction == None or direction == '<next>' or ifile == None:
+if direction == None:
     raise RuntimeError('Usage: hfst-push-weights.py INFILE -p [input|output]')
         
-istr = hfst.HfstInputStream(ifile)
+istr = hfst_commandline.get_one_hfst_input_stream(options)[0]
 ostr = hfst.HfstOutputStream(type=istr.get_type())
 
 while(not istr.is_eof()):
