@@ -27,6 +27,7 @@
 
 #include <iostream>
 #include <fstream>
+#include <memory>
 
 #include <cstdio>
 #include <cstdlib>
@@ -260,18 +261,16 @@ int main( int argc, char **argv ) {
     }
     verbose_printf("Reading from %s, writing to %s\n",
         inputfilename, outfilename);
-    char* format_description = hfst_strformat(output_type);
     if (hfst_format && (output_type != hfst::XFSM_TYPE))
       {
         verbose_printf("Writing %s format transducers with HFST3 headers\n",
-                       format_description);
+                       hfst_strformat(output_type));
       }
     else
       {
         verbose_printf("Writing %s format transducers without HFST specific"
-                       " headers\n", format_description);
+                       " headers\n", hfst_strformat(output_type));
       }
-    free(format_description);
 
     if (output_type == hfst::XFSM_TYPE)
       {
@@ -283,10 +282,10 @@ int main( int argc, char **argv ) {
       }
 
     // here starts the buffer handling part
-    HfstInputStream* instream = NULL;
+    std::unique_ptr<HfstInputStream> instream;
     try {
-      instream = (inputfile != stdin) ?
-        new HfstInputStream(inputfilename) : new HfstInputStream();
+      instream.reset((inputfile != stdin) ?
+        new HfstInputStream(inputfilename) : new HfstInputStream());
     }
     catch(const FileIsInGZFormatException e)
       {
@@ -312,13 +311,11 @@ int main( int argc, char **argv ) {
         return EXIT_FAILURE;
     }
 
-    HfstOutputStream* outstream = (outfile != stdout) ?
-      new HfstOutputStream(outfilename, output_type, hfst_format) :
-      new HfstOutputStream(output_type, hfst_format);
+    auto outstream = (outfile != stdout) ?
+      std::make_unique<HfstOutputStream>(outfilename, output_type, hfst_format) :
+      std::make_unique<HfstOutputStream>(output_type, hfst_format);
 
     retval = process_stream(*instream, *outstream);
-    delete instream;
-    delete outstream;
     free(inputfilename);
     free(outfilename);
     return retval;
