@@ -27,6 +27,7 @@
 
 #include <iostream>
 #include <fstream>
+#include <memory>
 
 #include <cstdio>
 #include <cstdlib>
@@ -1844,16 +1845,14 @@ process_stream(HfstInputStream& inputstream, FILE* outstream)
 
     if (!only_optimized_lookup)
       {
-        char* format_string = hfst_strformat(cascade[0].get_type());
         if (!silent) {
           warning(0, 0,
                   "It is not possible to perform fast lookups with %s "
                   "format automata.\n"
                   "Using HFST basic transducer format "
                   "and performing slow lookups",
-                  format_string);
+                  hfst_strformat(cascade[0].get_type()));
         }
-        free(format_string);
       }
     long filesize = -1;
     if (show_progress_bar)
@@ -2019,12 +2018,12 @@ int main( int argc, char **argv ) {
             infinite_begin_setf, infinite_lookupf, infinite_end_setf,
             epsilon_format, space_format, show_flags);
     // here starts the buffer handling part
-    HfstInputStream* instream = NULL;
+    std::unique_ptr<HfstInputStream> instream;
     try
       {
-        instream = (inputfile != stdin) ?
+        instream.reset((inputfile != stdin) ?
           new HfstInputStream(inputfilename) :
-          new HfstInputStream();
+          new HfstInputStream());
       }
     catch(const HfstException e)
       {
@@ -2037,7 +2036,6 @@ int main( int argc, char **argv ) {
     {
         fclose(outfile);
     }
-    delete instream;
     free(inputfilename);
     free(outfilename);
     return EXIT_SUCCESS;
