@@ -28,6 +28,7 @@
 
 #include <iostream>
 #include <fstream>
+#include <memory>
 
 #include <cstdio>
 #include <cstdlib>
@@ -784,12 +785,12 @@ int main( int argc, char **argv ) {
         inputfilename, outfilename);
 
     // here starts the buffer handling part
-    HfstInputStream* instream = NULL;
+    std::unique_ptr<HfstInputStream> instream;
     try
       {
-        instream = (inputfile != stdin) ?
+        instream.reset((inputfile != stdin) ?
           new HfstInputStream(inputfilename) :
-          new HfstInputStream();
+          new HfstInputStream());
       }
     catch(const HfstException e)
       {
