@@ -31,6 +31,7 @@
 
 #include <iostream>
 #include <fstream>
+#include <memory>
 
 #include <vector>
 #include <map>
@@ -337,12 +338,12 @@ process_stream(HfstOutputStream& outstream)
             harmonized_tmp = hfst::implementations::ConversionFunctions::
                 hfst_basic_transducer_to_hfst_ol(intermediate_tmp,
                                                  true, // weighted
-                                                 "", // no special options
+                                                 "empty_alphabet", // empty alphabet in RTNs, they'll use the main one
                                                  &harmonizer); // harmonize with this
             output_tmp = hfst::implementations::ConversionFunctions::
                 hfst_ol_to_hfst_transducer(harmonized_tmp);
             output_tmp->set_name(it->first);
-            outstream << *output_tmp;;
+            outstream << *output_tmp;
             delete it->second;
             delete intermediate_tmp;
             delete output_tmp;
@@ -384,9 +385,9 @@ int main( int argc, char **argv )
     verbose_printf("Reading from %s, writing to %s\n",
                    inputfilename, outfilename);
     // here starts the buffer handling part
-    HfstOutputStream* outstream = (outfile != stdout) ?
-        new HfstOutputStream(outfilename, hfst::HFST_OLW_TYPE) :
-        new HfstOutputStream(hfst::HFST_OLW_TYPE);
+    auto outstream = (outfile != stdout) ?
+        std::make_unique<HfstOutputStream>(outfilename, hfst::HFST_OLW_TYPE) :
+        std::make_unique<HfstOutputStream>(hfst::HFST_OLW_TYPE);
     process_stream(*outstream);
     free(inputfilename);
     free(outfilename);
