@@ -148,7 +148,7 @@ hfst_ol::PmatchContainer make_naive_tokenizer(HfstTransducer * dictionary)
     right_context->concatenate(*right_context_exit);
     delete left_context_exit; delete right_context_exit;
     std::string dict_name = dictionary->get_name();
-    if (dict_name == "") {
+    if (dict_name.empty()) {
         dict_name = "unknown_pmatch_tokenized_dict";
         dictionary->set_name(dict_name);
     }
@@ -276,7 +276,7 @@ int process_input_0delim(hfst_ol::PmatchContainer & container,
     ssize_t len = -1;
     while ((len = hfst_getdelim(&line, &bufsize, '\0', inputfile)) > 0) {
         bool escaped = false; // beginning of line is necessarily unescaped
-        for(size_t i = 0; i < len; ++i) {
+        for(ssize_t i = 0; i < len; ++i) {
             if(escaped) {
                 cur << line[i];
                 escaped = false;
@@ -303,9 +303,17 @@ int process_input_0delim(hfst_ol::PmatchContainer & container,
             }
             else if(!in_blank && line[i] == '\n') {
                 cur << line[i];
+                if (verbose) {
+                    std::cout << "processing: " << cur.str() << "\\n" <<
+                                 std::endl;
+                }
                 process_input_0delim_print(container, outstream, cur);
             }
             else if(line[i] == '\0') {
+                if (verbose) {
+                    std::cout << "processing: " << cur.str() << "\\0" <<
+                                 std::endl;
+                }
                 process_input_0delim_print(container, outstream, cur);
                 outstream << "<STREAMCMD:FLUSH>" << std::endl; // CG format uses this instead of \0
                 outstream.flush();
@@ -504,6 +512,7 @@ int parse_options(int argc, char** argv)
             settings.print_weights = true;
             settings.print_all = true;
             settings.dedupe = true;
+            settings.hack_uncompose = true;
             settings.verbose = false;
             if(settings.max_weight_classes == std::numeric_limits<int>::max()) {
                 settings.max_weight_classes = 2;
@@ -522,7 +531,9 @@ int parse_options(int argc, char** argv)
 #include "inc/getopt-cases-error.h"
         }
 
-
+    if (verbose) {
+        settings.verbose = true;
+    }
 
     }
 
